
/*
 * VMObject.h
 *
 * 
 *
 */

#include "jni.h"

void java_lang_VMObject_notify(JNIEnv* env,jobject o, jobject obj);
void java_lang_VMObject_notifyAll(JNIEnv* env, jobject o, jobject obj);
void java_lang_VMObject_wait
(
  JNIEnv* env,
  jclass VMclass,
  jobject obj,
  jlong millis,
  jint ns
);
jobject java_lang_VMObject_clone
(
  JNIEnv* env,
  jclass clazz,
  jobject obj
);

